.. :changelog:

History
-------

0.1.1 (2019-02-28)
++++++++++++++++++

* Delete content_object of upload on revert, too
* Store upload in another apps model if app_name is provided in process path /process/app_name
* Added some tests

0.1.0 (2018-11-14)
++++++++++++++++++

* First release on PyPI.
